netapp_ontap.models.ip_interface_svm API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.ip_interface_svm`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class IpInterfaceSvmSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the IpInterfaceSvm object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `ip GET POST PATCH`

    The ip field of the ip_interface_svm.

  `links GET`

    The links field of the ip_interface_svm.

  `location POST`

    The location field of the ip_interface_svm.

  `name GET POST`

    The name of the interface (optional).

    Example: lif1

  `service_policy GET POST PATCH`

    The service_policy field of the ip_interface_svm.

  `services GET`

    The services associated with the interface.

  `uuid GET`

    The UUID that uniquely identifies the interface.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412